Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Job ¶
type Job struct {
Type Type
// Enabled is set as true for backward compatibility. If the job needs to be disabled, it must be present in the config with this value as false.
Enabled bool `mapstructure:"enabled" default:"true"`
Interval string `mapstructure:"interval"`
Config Config `mapstructure:"config"`
}
type RevokeGrantsByUserCriteriaConfig ¶
type RevokeGrantsByUserCriteriaConfig struct {
IAM domain.IAMConfig `mapstructure:"iam"`
UserCriteria evaluator.Expression `mapstructure:"user_criteria"`
ReassignOwnershipTo evaluator.Expression `mapstructure:"reassign_ownership_to"`
DryRun bool `mapstructure:"dry_run"`
}
type Type ¶
type Type string
const ( TypeFetchResources Type = "fetch_resources" TypeExpiringGrantNotification Type = "expiring_grant_notification" TypeRevokeExpiredGrants Type = "revoke_expired_grants" TypeRevokeGrantsByUserCriteria Type = "revoke_grants_by_user_criteria" // Deprecated: use RevokeExpiredGrants instead TypeRevokeExpiredAccess Type = "revoke_expired_access" // Deprecated: use ExpiringGrantNotification instead TypeExpiringAccessNotification Type = "expiring_access_notification" )
Source Files
¶
Click to show internal directories.
Click to hide internal directories.